@@ -47,28 +47,41 @@ class DecimalEncoder(json.JSONEncoder):
 
 
 
-def update_dynamodb_item(tablename, itemKey = {}, updateMsg = {}):
+def update_dynamodb_item(tablename, itemKey = {}, updateMsg = {},session = boto3.Session(), dynamodbTableRes = None):
+    """[summary]
 
+    Args:
+        tablename ([type]): [description]
+        itemKey (dict, optional): [description]. Defaults to {}.
+        updateMsg (dict, optional): [description]. Defaults to {}.
+        session ([boto3.Session()], optional): [description]. Defaults to boto3.Session().
+        table_res ( [boto3.resource('dynamodb').Table], optional): [description]. Defaults to None.
 
+    Returns:
+        [type]: [description]
+    """
 
-    #DynamoDB tables
+    
+   
     try:
-        dynamodb = boto3.resource('dynamodb')
-        #dynamodb = session.resource('dynamodb')
-        ddbRequestStatus = dynamodb.Table(tablename)
-        updateMsgCleaned = clean_empty(updateMsg)
+        # Create new DynamoDB resource and table (Locally accessible)
+        if dynamodbTableRes is None:
+            dynamodb = session.resource('dynamodb')
+            dynamodbTableRes = dynamodb.Table(tablename)
+        
+         # Otherwise use the table resource passed to the function
+        else:
+            pass
 
     except Exception as e:
         print("Error opening the DynamoDb tables", e)
         return False
 
-
-    #Timestamp
+    #Add update timestamp and clean update data
     now = datetime.now()
     updated_at = now.strftime ("%Y-%m-%d %H:%M:%S")
     updateMsg['last_update_at'] = updated_at
-
-
+    updateMsgCleaned = clean_empty(updateMsg)
 
     #----------------------------------------------------------------------------------------
     #STEP 2 -  Update the request status in the DATA_REQUESTS_DYNAMODB_TABLE
@@ -88,13 +101,8 @@ def update_dynamodb_item(tablename, itemKey = {}, updateMsg = {}):
             
             i+=1
 
-
-        #print(UpdateExpression)
-        #print(ExpressionAttributeValues)
-        #print(ExpressionAttributeNames)
-
         #Update the table
-        response = ddbRequestStatus.update_item(
+        response = dynamodbTableRes.update_item(
             Key=itemKey,
             UpdateExpression=UpdateExpression[:-1],
             ExpressionAttributeValues=ExpressionAttributeValues,
